@@ -62,6 +62,7 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-7z-compressed-tar",    ".tar.7z",   N_("Tar compressed with 7z (.tar.7z)"), 0 },
 	{ "application/x-ace",                  ".ace",      N_("Ace (.ace)"), 0 },
 	{ "application/x-alz",                  ".alz",      NULL, 0 },
+	{ "application/x-ar",                   ".a",        N_("Ar (.a)"), 0 },
 	{ "application/x-ar",                   ".ar",       N_("Ar (.ar)"), 0 },
 	{ "application/x-arj",                  ".arj",      N_("Arj (.arj)"), 0 },
 	{ "application/x-bzip",                 ".bz2",      NULL, 0 },
@@ -108,6 +109,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".7z", "application/x-7z-compressed" },
 	{ ".ace", "application/x-ace" },
 	{ ".alz", "application/x-alz" },
+	{ ".a", "application/x-ar" },
 	{ ".ar", "application/x-ar" },
 	{ ".arj", "application/x-arj" },
 	{ ".bin", "application/x-stuffit" },
